@@ -54,7 +54,7 @@ def test_remove():
 
 
 def test_day_words():
-    voc = Vocabulary("191225.voc")
+    voc = Vocabulary("200229.voc", lang="En")
     words = voc.day_words()
     assert len(words) > 10000
 
@@ -62,4 +62,30 @@ def test_day_words():
 def test_remove_qgrams():
     voc = Vocabulary("191225.voc")
     voc.remove_qgrams()
-    assert len([x for x in voc.voc if x[:2] == "q:"]) == 0
\ No newline at end of file
+    assert len([x for x in voc.voc if x[:2] == "q:"]) == 0
+
+
+def test_previous_day():
+    from os.path import basename
+
+    voc = Vocabulary("200301.voc")
+    prev = voc.previous_day()
+    assert basename(prev._fname) == "200229.voc"
+
+
+def test_dict_functions():
+    voc = Vocabulary("200301.voc")
+
+    assert len(voc) == len([x for x in voc])
+    data = [k for k, v in voc.items()]
+    assert len(voc) == len(data)
+    assert data[0] in voc
+    assert "BLABLA" not in voc
+    assert voc.get("BLABLA") == 0
+    assert voc[data[0]] == voc.get(data[0])
+
+
+def test_remove_emojis():
+    voc = Vocabulary("200301.voc")
+    voc.remove_qgrams()
+    voc.remove_emojis()
